@@ -194,13 +194,18 @@ public class Utils {
 			throw new IllegalArgumentException("Item bean to manage cannot be null");
 
 		try(CloseableHttpClient httpClient = HttpClientBuilder.create().build();){
-
-			// send update to the knowledge base
-			GRSFUpdaterServiceClient.updateKB(httpClient, serviceUrl, bean, catalogue, username, fullName);
 			
-			// if there are merges, update the status of the other involved records
-			if(bean.isMergesInvolved())
-				updateStatusInvolvedRecords(bean, catalogue);
+			//ADDED BY FRANCESCO
+			if(Utils.isIntoPortal()) {
+
+				// send update to the knowledge base
+				GRSFUpdaterServiceClient.updateKB(httpClient, serviceUrl, bean, catalogue, username, fullName);
+				
+				// if there are merges, update the status of the other involved records
+				if(bean.isMergesInvolved())
+					updateStatusInvolvedRecords(bean, catalogue);
+			
+			}
 
 			// require social networking url
 			final String baseUrlSocial = SocialCommunications.getBaseUrlSocialService(httpServletRequest);
